@@ -1,3 +1,4 @@
+{-# LANGUAGE OverloadedStrings #-}
 module Main where
 
 import Control.Monad
@@ -12,11 +13,11 @@ file :: String
 file = "hello"
 
 write :: String -> IO ()
-write path = do
+write path =
     writeFile (path ++ '/':file) ""
 
 remove :: String -> IO ()
-remove path = do
+remove path =
     removeFile (path ++ '/':file)
 
 action :: String -> IO ()
@@ -34,9 +35,9 @@ main =
 
 expected :: [Event]
 expected =
-    [ Created   False file
-    , Opened    False (Just file)
-    , Modified  False (Just file)
-    , Closed    False (Just file) True
-    , Deleted   False file
+    [ Created   False "hello"
+    , Opened    False (Just "hello")
+    , Modified  False (Just "hello")
+    , Closed    False (Just "hello") True
+    , Deleted   False "hello"
     ]
